pub struct Invocation {
pub syntax: Spanned<Syntax>,
}Expand description
A shim for parsing the root level of a macro invocation, so that a session type may be written as a block w/o an extra layer of braces.
Fields
syntax: Spanned<Syntax>The spanned syntax representing a full invocation of the macro.
Implementations